
# Slot: affects expression in


Holds between a variant and an anatomical entity where the expression of the variant is located in.

URI: [biolink:affects_expression_in](https://w3id.org/biolink/vocab/affects_expression_in)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects](affects.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | GTEx:affects_expression_in |

